@@ -59,33 +59,32 @@ pub(crate) trait Context {
     fn context(self, message: impl Fn() -> String) -> Self;
 }
 
-#[cfg(all(not(target_os = "unknown"), feature = "default"))]
+#[cfg(all(
+    not(target_os = "unknown"),
+    any(feature = "default", feature = "unstable")
+))]
 mod timer {
-    pub type Timer = smol::Timer;
+    pub type Timer = async_io::Timer;
 }
 
 #[cfg(any(feature = "unstable", feature = "default"))]
 pub(crate) fn timer_after(dur: std::time::Duration) -> timer::Timer {
-    #[cfg(not(target_os = "unknown"))]
-    once_cell::sync::Lazy::force(&crate::rt::RUNTIME);
-
     Timer::after(dur)
 }
 
-#[cfg(any(
-    all(target_arch = "wasm32", feature = "default"),
-    all(feature = "unstable", not(feature = "default"))
-))]
+#[cfg(any(all(target_arch = "wasm32", feature = "default"),))]
 mod timer {
     use std::pin::Pin;
     use std::task::Poll;
 
+    use gloo_timers::future::TimeoutFuture;
+
     #[derive(Debug)]
-    pub(crate) struct Timer(futures_timer::Delay);
+    pub(crate) struct Timer(TimeoutFuture);
 
     impl Timer {
         pub(crate) fn after(dur: std::time::Duration) -> Self {
-            Timer(futures_timer::Delay::new(dur))
+            Timer(TimeoutFuture::new(dur.as_millis() as u32))
         }
     }
 
